@@ -114,15 +114,15 @@ _edje_text_fit_x(Edje *ed, Edje_Real_Part *ep,
    char *buf;
    int c1 = -1, c2 = -1, loop = 0, extra;
    size_t orig_len;
-   double sc;
+   FLOAT_T sc;
 
    sc = ed->scale;
-   if (sc == 0.0) sc = _edje_scale;
-   
+   if (sc == ZERO) sc = _edje_scale;
+
    *free_text = 0;
    if (sw <= 1) return "";
 
-   if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+   if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
    evas_object_text_font_set(ep->object, font, size);
    evas_object_text_text_set(ep->object, text);
 
@@ -161,7 +161,7 @@ _edje_text_fit_x(Edje *ed, Edje_Real_Part *ep,
     * FIXME: we might want to set a max string length somewhere...
     */
    extra = 1 + 3 + 3; /* terminator, leading and trailing ellipsis */
-   orig_len = MIN(orig_len, 8192 - extra);
+   orig_len = MIN(orig_len, ((size_t) 8192 - extra));
 
    if (!(buf = malloc(orig_len + extra)))
      return text;
@@ -216,7 +216,7 @@ _edje_text_fit_x(Edje *ed, Edje_Real_Part *ep,
 		  break;
 	       }
 	  }
-	else if ((c1 > 0 && c1 >= orig_len) || c2 == 0)
+	else if ((c1 > 0 && (size_t) c1 >= orig_len) || c2 == 0)
 	  {
 	     buf[0] = 0;
 	     break;
@@ -256,7 +256,7 @@ _edje_text_font_get(const char *base, const char *new, char **free_later)
 
    font_len = strlen(new);
    aux = strchr(base_style, ',');
-   style_len = (aux) ?  (aux - base_style) : strlen(base_style);
+   style_len = (aux) ? (aux - base_style) : (int) strlen(base_style);
 
    *free_later = malloc(font_len + style_len + 1);
    memcpy(*free_later, new, font_len);
@@ -302,7 +302,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
    Evas_Coord	 tw, th;
    Evas_Coord	 sw, sh;
    int		 inlined_font = 0, free_text = 0;
-   double        sc;
+   FLOAT_T       sc;
 
    sc = ed->scale;
    if (sc == 0.0) sc = _edje_scale;
@@ -389,7 +389,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
         if (inlined_font) evas_object_text_font_source_set(ep->object, ed->path);
 	else evas_object_text_font_source_set(ep->object, NULL);
 
-	if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+	if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 	evas_object_text_font_set(ep->object, font, size);
 	evas_object_text_text_set(ep->object, text);
 	part_get_geometry(ep, &tw, &th);
@@ -406,7 +406,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
 		  if (inlined_font) evas_object_text_font_source_set(ep->object, ed->path);
 		  else evas_object_text_font_source_set(ep->object, NULL);
 
-		  if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+		  if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 		  evas_object_text_font_set(ep->object, font, size);
 		  part_get_geometry(ep, &tw, &th);
 		  if ((size > 0) && (tw == 0)) break;
@@ -425,7 +425,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
 		  if (inlined_font) evas_object_text_font_source_set(ep->object, ed->path);
 		  else evas_object_text_font_source_set(ep->object, NULL);
 
-		  if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+		  if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 		  evas_object_text_font_set(ep->object, font, size);
 		  part_get_geometry(ep, &tw, &th);
 		  if ((size > 0) && (tw == 0)) break;
@@ -443,7 +443,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
         if (inlined_font) evas_object_text_font_source_set(ep->object, ed->path);
 	else evas_object_text_font_source_set(ep->object, NULL);
 
-	if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+	if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 	evas_object_text_font_set(ep->object, font, size);
 	evas_object_text_text_set(ep->object, text);
 	part_get_geometry(ep, &tw, &th);
@@ -464,7 +464,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
 		  if (inlined_font) evas_object_text_font_source_set(ep->object, ed->path);
 		  else evas_object_text_font_source_set(ep->object, NULL);
 
-		  if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+		  if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 		  evas_object_text_font_set(ep->object, font, size);
 		  part_get_geometry(ep, &tw, &th);
 		  if ((size > 0) && (th == 0)) break;
@@ -475,7 +475,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
 	  {
 	     int current;
 
-	     if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+	     if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 	     evas_object_text_font_set(ep->object, font, 10);
 	     part_get_geometry(ep, &tw, &th);
 
@@ -500,7 +500,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
 		    {
 		       current = (top + bottom) / 2;
 
-		       if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+		       if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 		       evas_object_text_font_set(ep->object, font, current);
 		       part_get_geometry(ep, &tw, &th);
 
@@ -514,7 +514,7 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
 	       {
 		  current++;
 
-		  if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+		  if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 		  evas_object_text_font_set(ep->object, font, current);
 		  part_get_geometry(ep, &tw, &th);
 	       } while (th <= sh);
@@ -546,12 +546,12 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
    if (inlined_font) evas_object_text_font_source_set(ep->object, ed->path);
    else evas_object_text_font_source_set(ep->object, NULL);
 
-   if (ep->part->scale) evas_object_scale_set(ep->object, sc);
+   if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
    evas_object_text_font_set(ep->object, font, size);
    evas_object_text_text_set(ep->object, text);
    part_get_geometry(ep, &tw, &th);
-   ep->text.offset.x = ((sw - tw) * params->type.text.align.x);
-   ep->text.offset.y = ((sh - th) * params->type.text.align.y);
+   ep->text.offset.x = TO_INT(SCALE(params->type.text.align.x, (sw - tw)));
+   ep->text.offset.y = TO_INT(SCALE(params->type.text.align.y, (sh - th)));
 
    evas_object_move(ep->object,
 		    ed->x + params->x + ep->text.offset.x,
